<?php

/**
 * @version    CVS: 1.0.0
 * @package    Com_Record
 * @author     Eric Fagault <ericfagault34@gmail.com>
 * @copyright  2021 Eric Fagault
 * @license    GNU General Public License version 2 ou version ultérieure ; Voir LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use Joomla\CMS\Component\Router\RouterViewConfiguration;
use Joomla\CMS\Component\Router\RouterView;
use Joomla\CMS\Component\Router\Rules\StandardRules;
use Joomla\CMS\Component\Router\Rules\NomenuRules;
use Joomla\CMS\Component\Router\Rules\MenuRules;
use Joomla\CMS\Factory;
use Joomla\CMS\Categories\Categories;

/**
 * Class RecordRouter
 *
 */
class RecordRouter extends RouterView
{
	private $noIDs;
	public function __construct($app = null, $menu = null)
	{
		$params = JComponentHelper::getComponent('com_record')->params;
		$this->noIDs = (bool) $params->get('sef_ids');
		
		$perfs = new RouterViewConfiguration('perfs');
		$this->registerView($perfs);
			$perf = new RouterViewConfiguration('perf');
			$perf->setKey('id')->setParent($perfs);
			$this->registerView($perf);
			$perfform = new RouterViewConfiguration('perfform');
			$perfform->setKey('id');
			$this->registerView($perfform);

		parent::__construct($app, $menu);

		$this->attachRule(new MenuRules($this));

		if ($params->get('sef_advanced', 0))
		{
			$this->attachRule(new StandardRules($this));
			$this->attachRule(new NomenuRules($this));
		}
		else
		{
			JLoader::register('RecordRulesLegacy', __DIR__ . '/helpers/legacyrouter.php');
			JLoader::register('RecordHelpersRecord', __DIR__ . '/helpers/record.php');
			$this->attachRule(new RecordRulesLegacy($this));
		}
	}


	
		/**
		 * Method to get the segment(s) for an perf
		 *
		 * @param   string  $id     ID of the perf to retrieve the segments for
		 * @param   array   $query  The request that is built right now
		 *
		 * @return  array|string  The segments of this item
		 */
		public function getPerfSegment($id, $query)
		{
			return array((int) $id => $id);
		}
			/**
			 * Method to get the segment(s) for an perfform
			 *
			 * @param   string  $id     ID of the perfform to retrieve the segments for
			 * @param   array   $query  The request that is built right now
			 *
			 * @return  array|string  The segments of this item
			 */
			public function getPerfformSegment($id, $query)
			{
				return $this->getPerfSegment($id, $query);
			}

	
		/**
		 * Method to get the segment(s) for an perf
		 *
		 * @param   string  $segment  Segment of the perf to retrieve the ID for
		 * @param   array   $query    The request that is parsed right now
		 *
		 * @return  mixed   The id of this item or false
		 */
		public function getPerfId($segment, $query)
		{
			return (int) $segment;
		}
			/**
			 * Method to get the segment(s) for an perfform
			 *
			 * @param   string  $segment  Segment of the perfform to retrieve the ID for
			 * @param   array   $query    The request that is parsed right now
			 *
			 * @return  mixed   The id of this item or false
			 */
			public function getPerfformId($segment, $query)
			{
				return $this->getPerfId($segment, $query);
			}
}
